@@ -846,14 +846,14 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
     if ((MagickSizeType) bmp_info.file_size != blob_size)
       {
-        ExceptionType
-          severity;
+        const char
+          *option;
 
-        severity=CorruptImageWarning;
-        if ((MagickSizeType) bmp_info.file_size > blob_size + 4)
-          severity=CorruptImageError;
-        (void) ThrowMagickException(exception,GetMagickModule(),severity,
-          "LengthAndFilesizeDoNotMatch","`%s'",image->filename);
+        option=GetImageOption(image_info,"bmp:ignore-filesize");
+        if (IsStringTrue(option) == MagickFalse)
+          (void) ThrowMagickException(exception,GetMagickModule(),
+            CorruptImageError,"LengthAndFilesizeDoNotMatch","`%s'",
+            image->filename);
       }
     if (bmp_info.width <= 0)
       ThrowReaderException(CorruptImageError,"NegativeOrZeroImageSize");
@@ -1718,8 +1718,8 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (((image->columns << 3) != (int) (image->columns << 3)) ||
-      ((image->rows << 3) != (int) (image->rows << 3)))
+  if (((image->columns << 3) != (size_t) ((int) (image->columns << 3))) ||
+      ((image->rows << 3) != (size_t) ((int) (image->rows << 3))))
     ThrowWriterException(ImageError,"WidthOrHeightExceedsLimit");
   type=4;
   if (LocaleCompare(image_info->magick,"BMP2") == 0)
