@@ -232,7 +232,7 @@ static Image *ReadHEICImage(const ImageInfo *image_info,
           file_data=RelinquishMagickMemory(file_data);
           ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
         }
-      color_buffer=(unsigned char *) AcquireMagickMemory(length);
+      color_buffer=(unsigned char *) AcquireQuantumMemory(1,length);
       if (color_buffer != (unsigned char *) NULL)
         {
           error=heif_image_handle_get_raw_color_profile(image_handle,
@@ -274,7 +274,7 @@ static Image *ReadHEICImage(const ImageInfo *image_info,
           file_data=RelinquishMagickMemory(file_data);
           ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
         }
-      exif_buffer=(unsigned char*) AcquireMagickMemory(exif_size);
+      exif_buffer=(unsigned char*) AcquireQuantumMemory(1,exif_size);
       if (exif_buffer != (unsigned char*) NULL)
         {
           error=heif_image_handle_get_metadata(image_handle,
@@ -334,16 +334,15 @@ static Image *ReadHEICImage(const ImageInfo *image_info,
     Copy HEIF image into ImageMagick data structures
   */
   (void) SetImageColorspace(image,YCbCrColorspace);
-  decode_options=(struct heif_decoding_options *) NULL;
+  decode_options=heif_decoding_options_alloc();
+#if LIBHEIF_NUMERIC_VERSION > 0x01070000
+  decode_options->convert_hdr_to_8bit=1;
+#endif
   if (preserve_orientation == MagickTrue)
-    {
-      decode_options=heif_decoding_options_alloc();
-      decode_options->ignore_transformations=1;
-    }
+    decode_options->ignore_transformations=1;
   error=heif_decode_image(image_handle,&heif_image,heif_colorspace_YCbCr,
     heif_chroma_420,decode_options);
-  if (decode_options != (struct heif_decoding_options *) NULL)
-    heif_decoding_options_free(decode_options);
+  heif_decoding_options_free(decode_options);
   if (IsHeifSuccess(&error,image) == MagickFalse)
     {
       heif_image_handle_release(image_handle);
