@@ -484,7 +484,7 @@ static boolean ReadComment(j_decompress_ptr jpeg_info)
 static boolean ReadICCProfile(j_decompress_ptr jpeg_info)
 {
   char
-    magick[12];
+    magick[13];
 
   ErrorManager
     *error_manager;
@@ -524,6 +524,7 @@ static boolean ReadICCProfile(j_decompress_ptr jpeg_info)
     }
   for (i=0; i < 12; i++)
     magick[i]=(char) GetCharacter(jpeg_info);
+  magick[i]='\0';
   if (LocaleCompare(magick,ICC_PROFILE) != 0)
     {
       /*
@@ -1205,9 +1206,7 @@ static Image *ReadJPEGImage_(const ImageInfo *image_info,
       if (IsOptionMember("APP",option) == MagickFalse)
         jpeg_set_marker_processor(jpeg_info,(int) (JPEG_APP0+i),ReadProfile);
   i=(ssize_t) jpeg_read_header(jpeg_info,TRUE);
-  if ((image_info->colorspace == YCbCrColorspace) ||
-      (image_info->colorspace == Rec601YCbCrColorspace) ||
-      (image_info->colorspace == Rec709YCbCrColorspace))
+  if (IsYCbCrCompatibleColorspace(image_info->colorspace) != MagickFalse)
     jpeg_info->out_color_space=JCS_YCbCr;
   /*
     Set image resolution.
@@ -2163,7 +2162,7 @@ static void WriteProfile(j_compress_ptr jpeg_info,Image *image)
         }
       }
     if ((LocaleCompare(name,"XMP") == 0) &&
-        (GetStringInfoLength(profile) <= 65502))
+       (GetStringInfoLength(profile) < (65533 - sizeof(xmp_namespace))))
       {
         StringInfo
           *xmp_profile;
@@ -2174,15 +2173,11 @@ static void WriteProfile(j_compress_ptr jpeg_info,Image *image)
         xmp_profile=StringToStringInfo(xmp_namespace);
         if (xmp_profile != (StringInfo *) NULL)
           {
-            if (profile != (StringInfo *) NULL)
-              ConcatenateStringInfo(xmp_profile,profile);
+            ConcatenateStringInfo(xmp_profile,profile);
             GetStringInfoDatum(xmp_profile)[XmpNamespaceExtent]='\0';
-            for (i=0; i < (ssize_t) GetStringInfoLength(xmp_profile); i+=65533L)
-            {
-              length=MagickMin(GetStringInfoLength(xmp_profile)-i,65533L);
-              jpeg_write_marker(jpeg_info,XML_MARKER,
-                GetStringInfoDatum(xmp_profile)+i,(unsigned int) length);
-            }
+            length=GetStringInfoLength(xmp_profile);
+            jpeg_write_marker(jpeg_info,XML_MARKER,
+              GetStringInfoDatum(xmp_profile),(unsigned int) length);
             xmp_profile=DestroyStringInfo(xmp_profile);
           }
       }
