@@ -103,6 +103,16 @@ static inline MagickBooleanType IsGrayColorspace(
   return(MagickFalse);
 }
 
+static inline MagickBooleanType IsHueCompatibleColorspace(
+  const ColorspaceType colorspace)
+{
+  if ((colorspace == HCLColorspace) || (colorspace == HCLpColorspace) ||
+      (colorspace == HSBColorspace) || (colorspace == HSIColorspace) ||
+      (colorspace == HSLColorspace) || (colorspace == HSVColorspace))
+    return(MagickTrue);
+  return(MagickFalse);
+}
+
 static inline MagickBooleanType IsRGBColorspace(const ColorspaceType colorspace)
 {
   if ((colorspace == RGBColorspace) || (colorspace == scRGBColorspace) ||
@@ -129,6 +139,16 @@ static inline MagickBooleanType IssRGBCompatibleColorspace(
   return(MagickFalse);
 }
 
+static inline MagickBooleanType IsYCbCrCompatibleColorspace(
+  const ColorspaceType colorspace)
+{
+  if ((colorspace == YCbCrColorspace) ||
+      (colorspace == Rec709YCbCrColorspace) ||
+      (colorspace == Rec601YCbCrColorspace))
+    return(MagickTrue);
+  return(MagickFalse);
+}
+
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
