@@ -246,9 +246,7 @@ MagickExport Image *CompareImageChannels(Image *image,
     Generate difference image.
   */
   status=MagickTrue;
-  fuzz=(double) MagickMin(GetNumberChannels(image,channel),
-    GetNumberChannels(reconstruct_image,channel))*
-    GetFuzzyColorDistance(image,reconstruct_image);
+  fuzz=GetFuzzyColorDistance(image,reconstruct_image);
   GetMagickPixelPacket(image,&zero);
   image_view=AcquireVirtualCacheView(image,exception);
   reconstruct_view=AcquireVirtualCacheView(reconstruct_image,exception);
@@ -301,9 +299,6 @@ MagickExport Image *CompareImageChannels(Image *image,
     reconstruct_pixel=zero;
     for (x=0; x < (ssize_t) columns; x++)
     {
-      double
-        distance;
-
       MagickStatusType
         difference;
 
@@ -311,7 +306,6 @@ MagickExport Image *CompareImageChannels(Image *image,
       SetMagickPixelPacket(reconstruct_image,q,reconstruct_indexes+x,
         &reconstruct_pixel);
       difference=MagickFalse;
-      distance=0.0;
       if (channel == CompositeChannels)
         {
           if (IsMagickColorSimilar(&pixel,&reconstruct_pixel) == MagickFalse)
@@ -321,6 +315,7 @@ MagickExport Image *CompareImageChannels(Image *image,
         {
           double
             Da,
+            distance,
             pixel,
             Sa;
 
@@ -331,21 +326,21 @@ MagickExport Image *CompareImageChannels(Image *image,
           if ((channel & RedChannel) != 0)
             {
               pixel=Sa*GetPixelRed(p)-Da*GetPixelRed(q);
-              distance+=pixel*pixel;
+              distance=pixel*pixel;
               if (distance >= fuzz)
                 difference=MagickTrue;
             }
           if ((channel & GreenChannel) != 0)
             {
               pixel=Sa*GetPixelGreen(p)-Da*GetPixelGreen(q);
-              distance+=pixel*pixel;
+              distance=pixel*pixel;
               if (distance >= fuzz)
                 difference=MagickTrue;
             }
           if ((channel & BlueChannel) != 0)
             {
               pixel=Sa*GetPixelBlue(p)-Da*GetPixelBlue(q);
-              distance+=pixel*pixel;
+              distance=pixel*pixel;
               if (distance >= fuzz)
                 difference=MagickTrue;
             }
@@ -353,7 +348,7 @@ MagickExport Image *CompareImageChannels(Image *image,
               (image->matte != MagickFalse))
             {
               pixel=(double) GetPixelOpacity(p)-GetPixelOpacity(q);
-              distance+=pixel*pixel;
+              distance=pixel*pixel;
               if (distance >= fuzz)
                 difference=MagickTrue;
             }
@@ -361,7 +356,7 @@ MagickExport Image *CompareImageChannels(Image *image,
               (image->colorspace == CMYKColorspace))
             {
               pixel=Sa*indexes[x]-Da*reconstruct_indexes[x];
-              distance+=pixel*pixel;
+              distance=pixel*pixel;
               if (distance >= fuzz)
                 difference=MagickTrue;
             }
@@ -461,9 +456,7 @@ static MagickBooleanType GetAbsoluteDistortion(const Image *image,
     Compute the absolute difference in pixels between two images.
   */
   status=MagickTrue;
-  fuzz=(double) MagickMin(GetNumberChannels(image,channel),
-    GetNumberChannels(reconstruct_image,channel))*
-    GetFuzzyColorDistance(image,reconstruct_image);
+  fuzz=GetFuzzyColorDistance(image,reconstruct_image);
   rows=MagickMax(image->rows,reconstruct_image->rows);
   columns=MagickMax(image->columns,reconstruct_image->columns);
   image_view=AcquireVirtualCacheView(image,exception);
@@ -517,11 +510,10 @@ static MagickBooleanType GetAbsoluteDistortion(const Image *image,
         (QuantumRange-OpaqueOpacity));
       Da=QuantumScale*(image->matte != MagickFalse ? GetPixelAlpha(q) :
         (QuantumRange-OpaqueOpacity));
-      distance=0.0;
       if ((channel & RedChannel) != 0)
         {
           pixel=Sa*GetPixelRed(p)-Da*GetPixelRed(q);
-          distance+=pixel*pixel;
+          distance=pixel*pixel;
           if (distance >= fuzz)
             {
               channel_distortion[RedChannel]++;
@@ -531,7 +523,7 @@ static MagickBooleanType GetAbsoluteDistortion(const Image *image,
       if ((channel & GreenChannel) != 0)
         {
           pixel=Sa*GetPixelGreen(p)-Da*GetPixelGreen(q);
-          distance+=pixel*pixel;
+          distance=pixel*pixel;
           if (distance >= fuzz)
             {
               channel_distortion[GreenChannel]++;
@@ -541,7 +533,7 @@ static MagickBooleanType GetAbsoluteDistortion(const Image *image,
       if ((channel & BlueChannel) != 0)
         {
           pixel=Sa*GetPixelBlue(p)-Da*GetPixelBlue(q);
-          distance+=pixel*pixel;
+          distance=pixel*pixel;
           if (distance >= fuzz)
             {
               channel_distortion[BlueChannel]++;
@@ -552,7 +544,7 @@ static MagickBooleanType GetAbsoluteDistortion(const Image *image,
           (image->matte != MagickFalse))
         {
           pixel=(double) GetPixelOpacity(p)-GetPixelOpacity(q);
-          distance+=pixel*pixel;
+          distance=pixel*pixel;
           if (distance >= fuzz)
             {
               channel_distortion[OpacityChannel]++;
@@ -563,7 +555,7 @@ static MagickBooleanType GetAbsoluteDistortion(const Image *image,
           (image->colorspace == CMYKColorspace))
         {
           pixel=Sa*indexes[x]-Da*reconstruct_indexes[x];
-          distance+=pixel*pixel;
+          distance=pixel*pixel;
           if (distance >= fuzz)
             {
               channel_distortion[BlackChannel]++;
