@@ -17,13 +17,13 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2017 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://www.imagemagick.org/script/license.php                           %
+%    https://imagemagick.org/script/license.php                               %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -316,7 +316,7 @@ MagickExport Image *CannyEdgeImage(const Image *image,const double radius,
   status=MagickTrue;
   edge_view=AcquireVirtualCacheView(edge_image,exception);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(edge_image,edge_image,edge_image->rows,1)
 #endif
   for (y=0; y < (ssize_t) edge_image->rows; y++)
@@ -363,7 +363,7 @@ MagickExport Image *CannyEdgeImage(const Image *image,const double radius,
           { -1.0, -1.0 }
         };
 
-      (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
+      (void) memset(&pixel,0,sizeof(pixel));
       dx=0.0;
       dy=0.0;
       kernel_pixels=p;
@@ -428,7 +428,7 @@ MagickExport Image *CannyEdgeImage(const Image *image,const double radius,
   min=element.intensity;
   edge_view=AcquireAuthenticCacheView(edge_image,exception);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(edge_image,edge_image,edge_image->rows,1)
 #endif
   for (y=0; y < (ssize_t) edge_image->rows; y++)
@@ -523,10 +523,10 @@ MagickExport Image *CannyEdgeImage(const Image *image,const double radius,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-        #pragma omp critical (MagickCore_CannyEdgeImage)
+        #pragma omp atomic
 #endif
-        proceed=SetImageProgress(image,CannyEdgeImageTag,progress++,
-          image->rows);
+        progress++;
+        proceed=SetImageProgress(image,CannyEdgeImageTag,progress,image->rows);
         if (proceed == MagickFalse)
           status=MagickFalse;
       }
@@ -689,7 +689,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
     sizeof(*channel_features));
   if (channel_features == (ChannelFeatures *) NULL)
     ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
-  (void) ResetMagickMemory(channel_features,0,length*
+  (void) memset(channel_features,0,length*
     sizeof(*channel_features));
   /*
     Form grays.
@@ -714,7 +714,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
   status=MagickTrue;
   image_view=AcquireVirtualCacheView(image,exception);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,image->rows,1)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
@@ -762,7 +762,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
         channel_features);
       return(channel_features);
     }
-  (void) ResetMagickMemory(&gray,0,sizeof(gray));
+  (void) memset(&gray,0,sizeof(gray));
   for (i=0; i <= (ssize_t) MaxMap; i++)
   {
     if (grays[i].red != ~0U)
@@ -838,20 +838,20 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
         ResourceLimitError,"MemoryAllocationFailed","`%s'",image->filename);
       return(channel_features);
     }
-  (void) ResetMagickMemory(&correlation,0,sizeof(correlation));
-  (void) ResetMagickMemory(density_x,0,2*(number_grays+1)*sizeof(*density_x));
-  (void) ResetMagickMemory(density_xy,0,2*(number_grays+1)*sizeof(*density_xy));
-  (void) ResetMagickMemory(density_y,0,2*(number_grays+1)*sizeof(*density_y));
-  (void) ResetMagickMemory(&mean,0,sizeof(mean));
-  (void) ResetMagickMemory(sum,0,number_grays*sizeof(*sum));
-  (void) ResetMagickMemory(&sum_squares,0,sizeof(sum_squares));
-  (void) ResetMagickMemory(density_xy,0,2*number_grays*sizeof(*density_xy));
-  (void) ResetMagickMemory(&entropy_x,0,sizeof(entropy_x));
-  (void) ResetMagickMemory(&entropy_xy,0,sizeof(entropy_xy));
-  (void) ResetMagickMemory(&entropy_xy1,0,sizeof(entropy_xy1));
-  (void) ResetMagickMemory(&entropy_xy2,0,sizeof(entropy_xy2));
-  (void) ResetMagickMemory(&entropy_y,0,sizeof(entropy_y));
-  (void) ResetMagickMemory(&variance,0,sizeof(variance));
+  (void) memset(&correlation,0,sizeof(correlation));
+  (void) memset(density_x,0,2*(number_grays+1)*sizeof(*density_x));
+  (void) memset(density_xy,0,2*(number_grays+1)*sizeof(*density_xy));
+  (void) memset(density_y,0,2*(number_grays+1)*sizeof(*density_y));
+  (void) memset(&mean,0,sizeof(mean));
+  (void) memset(sum,0,number_grays*sizeof(*sum));
+  (void) memset(&sum_squares,0,sizeof(sum_squares));
+  (void) memset(density_xy,0,2*number_grays*sizeof(*density_xy));
+  (void) memset(&entropy_x,0,sizeof(entropy_x));
+  (void) memset(&entropy_xy,0,sizeof(entropy_xy));
+  (void) memset(&entropy_xy1,0,sizeof(entropy_xy1));
+  (void) memset(&entropy_xy2,0,sizeof(entropy_xy2));
+  (void) memset(&entropy_y,0,sizeof(entropy_y));
+  (void) memset(&variance,0,sizeof(variance));
   for (i=0; i < (ssize_t) number_grays; i++)
   {
     cooccurrence[i]=(ChannelStatistics *) AcquireQuantumMemory(number_grays,
@@ -860,9 +860,9 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
     if ((cooccurrence[i] == (ChannelStatistics *) NULL) ||
         (Q[i] == (ChannelStatistics *) NULL))
       break;
-    (void) ResetMagickMemory(cooccurrence[i],0,number_grays*
+    (void) memset(cooccurrence[i],0,number_grays*
       sizeof(**cooccurrence));
-    (void) ResetMagickMemory(Q[i],0,number_grays*sizeof(**Q));
+    (void) memset(Q[i],0,number_grays*sizeof(**Q));
   }
   if (i < (ssize_t) number_grays)
     {
@@ -1094,7 +1094,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
     Compute texture features.
   */
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,number_grays,1)
 #endif
   for (i=0; i < 4; i++)
@@ -1279,7 +1279,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
     Compute more texture features.
   */
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,number_grays,1)
 #endif
   for (i=0; i < 4; i++)
@@ -1355,7 +1355,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
     Compute more texture features.
   */
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,number_grays,1)
 #endif
   for (i=0; i < 4; i++)
@@ -1471,10 +1471,10 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
   /*
     Compute more texture features.
   */
-  (void) ResetMagickMemory(&variance,0,sizeof(variance));
-  (void) ResetMagickMemory(&sum_squares,0,sizeof(sum_squares));
+  (void) memset(&variance,0,sizeof(variance));
+  (void) memset(&sum_squares,0,sizeof(sum_squares));
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,number_grays,1)
 #endif
   for (i=0; i < 4; i++)
@@ -1626,7 +1626,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
     Compute more texture features.
   */
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,number_grays,1)
 #endif
   for (i=0; i < 4; i++)
@@ -1642,7 +1642,7 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
       ChannelStatistics
         pixel;
 
-      (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
+      (void) memset(&pixel,0,sizeof(pixel));
       for (y=0; y < (ssize_t) number_grays; y++)
       {
         register ssize_t
@@ -1667,25 +1667,35 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
           /*
             Maximum Correlation Coefficient.
           */
-          Q[z][y].direction[i].red+=cooccurrence[z][x].direction[i].red*
-            cooccurrence[y][x].direction[i].red/density_x[z].direction[i].red/
-            density_y[x].direction[i].red;
-          Q[z][y].direction[i].green+=cooccurrence[z][x].direction[i].green*
-            cooccurrence[y][x].direction[i].green/
-            density_x[z].direction[i].green/density_y[x].direction[i].red;
-          Q[z][y].direction[i].blue+=cooccurrence[z][x].direction[i].blue*
-            cooccurrence[y][x].direction[i].blue/density_x[z].direction[i].blue/
-            density_y[x].direction[i].blue;
+          if ((fabs(density_x[z].direction[i].red) > MagickEpsilon) &&
+              (fabs(density_y[x].direction[i].red) > MagickEpsilon))
+            Q[z][y].direction[i].red+=cooccurrence[z][x].direction[i].red*
+              cooccurrence[y][x].direction[i].red/density_x[z].direction[i].red/
+              density_y[x].direction[i].red;
+          if ((fabs(density_x[z].direction[i].green) > MagickEpsilon) &&
+              (fabs(density_y[x].direction[i].red) > MagickEpsilon))
+            Q[z][y].direction[i].green+=cooccurrence[z][x].direction[i].green*
+              cooccurrence[y][x].direction[i].green/
+              density_x[z].direction[i].green/density_y[x].direction[i].red;
+          if ((fabs(density_x[z].direction[i].blue) > MagickEpsilon) &&
+              (fabs(density_y[x].direction[i].blue) > MagickEpsilon))
+            Q[z][y].direction[i].blue+=cooccurrence[z][x].direction[i].blue*
+              cooccurrence[y][x].direction[i].blue/
+              density_x[z].direction[i].blue/density_y[x].direction[i].blue;
           if (image->colorspace == CMYKColorspace)
-            Q[z][y].direction[i].index+=cooccurrence[z][x].direction[i].index*
-              cooccurrence[y][x].direction[i].index/
-              density_x[z].direction[i].index/density_y[x].direction[i].index;
+            if ((fabs(density_x[z].direction[i].index) > MagickEpsilon) &&
+                (fabs(density_y[x].direction[i].index) > MagickEpsilon))
+              Q[z][y].direction[i].index+=cooccurrence[z][x].direction[i].index*
+                cooccurrence[y][x].direction[i].index/
+                density_x[z].direction[i].index/density_y[x].direction[i].index;
           if (image->matte != MagickFalse)
-            Q[z][y].direction[i].opacity+=
-              cooccurrence[z][x].direction[i].opacity*
-              cooccurrence[y][x].direction[i].opacity/
-              density_x[z].direction[i].opacity/
-              density_y[x].direction[i].opacity;
+            if ((fabs(density_x[z].direction[i].opacity) > MagickEpsilon) &&
+                (fabs(density_y[x].direction[i].opacity) > MagickEpsilon))
+              Q[z][y].direction[i].opacity+=
+                cooccurrence[z][x].direction[i].opacity*
+                cooccurrence[y][x].direction[i].opacity/
+                density_x[z].direction[i].opacity/
+                density_y[x].direction[i].opacity;
         }
       }
       channel_features[RedChannel].contrast[i]+=z*z*pixel.direction[i].red;
@@ -1747,12 +1757,12 @@ MagickExport ChannelFeatures *GetImageChannelFeatures(const Image *image,
 %  recommand Canny) to identify lines in the image.  The algorithm accumulates
 %  counts for every white pixel for every possible orientation (for angles from
 %  0 to 179 in 1 degree increments) and distance from the center of the image to
-%  the corner (in 1 px increments) and stores the counts in an accumulator matrix
-%  of angle vs distance. The size of the accumulator is 180x(diagonal/2). Next
-%  it searches this space for peaks in counts and converts the locations of the
-%  peaks to slope and intercept in the normal x,y input image space. Use the
-%  slope/intercepts to find the endpoints clipped to the bounds of the image. The
-%  lines are then drawn. The counts are a measure of the length of the lines
+%  the corner (in 1 px increments) and stores the counts in an accumulator
+%  matrix of angle vs distance. The size of the accumulator is 180x(diagonal/2).%  Next it searches this space for peaks in counts and converts the locations
+%  of the peaks to slope and intercept in the normal x,y input image space. Use
+%  the slope/intercepts to find the endpoints clipped to the bounds of the
+%  image. The lines are then drawn. The counts are a measure of the length of
+%  the lines.
 %
 %  The format of the HoughLineImage method is:
 %
@@ -1829,11 +1839,11 @@ static Image *RenderHoughLines(const ImageInfo *image_info,const size_t columns,
     draw_info->primitive=FileToString(image->filename,~0UL,exception);
   else
     {
-      draw_info->primitive=(char *) AcquireMagickMemory((size_t)
+      draw_info->primitive=(char *) AcquireQuantumMemory(1,(size_t)
         GetBlobSize(image)+1);
       if (draw_info->primitive != (char *) NULL)
         {
-          (void) CopyMagickMemory(draw_info->primitive,GetBlobStreamData(image),
+          (void) memcpy(draw_info->primitive,GetBlobStreamData(image),
             (size_t) GetBlobSize(image));
           draw_info->primitive[GetBlobSize(image)]='\0';
         }
@@ -1967,10 +1977,10 @@ MagickExport Image *HoughLineImage(const Image *image,const size_t width,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-        #pragma omp critical (MagickCore_HoughLineImage)
+        #pragma omp atomic
 #endif
-        proceed=SetImageProgress(image,HoughLineImageTag,progress++,
-          image->rows);
+        progress++;
+        proceed=SetImageProgress(image,HoughLineImageTag,progress,image->rows);
         if (proceed == MagickFalse)
           status=MagickFalse;
       }
@@ -1999,6 +2009,10 @@ MagickExport Image *HoughLineImage(const Image *image,const size_t width,
     (double) image->columns,(double) image->rows);
   if (write(file,message,strlen(message)) != (ssize_t) strlen(message))
     status=MagickFalse;
+  (void) FormatLocaleString(message,MaxTextExtent,
+    "# x1,y1  x2,y2 # count angle distance\n");
+  if (write(file,message,strlen(message)) != (ssize_t) strlen(message))
+    status=MagickFalse;
   line_count=image->columns > image->rows ? image->columns/4 : image->rows/4;
   if (threshold != 0)
     line_count=threshold;
@@ -2080,7 +2094,8 @@ MagickExport Image *HoughLineImage(const Image *image,const size_t width,
                 cos(DegreesToRadians((double) x))+(image->columns/2.0);
             }
           (void) FormatLocaleString(message,MaxTextExtent,
-            "line %g,%g %g,%g  # %g\n",line.x1,line.y1,line.x2,line.y2,maxima);
+            "line %g,%g %g,%g  # %g %g %g\n",line.x1,line.y1,line.x2,line.y2,
+            maxima,(double) x,(double) y);
           if (write(file,message,strlen(message)) != (ssize_t) strlen(message))
             status=MagickFalse;
         }
@@ -2195,7 +2210,7 @@ MagickExport Image *MeanShiftImage(const Image *image,const size_t width,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
-  mean_image=CloneImage(image,image->columns,image->rows,MagickTrue,exception);
+  mean_image=CloneImage(image,0,0,MagickTrue,exception);
   if (mean_image == (Image *) NULL)
     return((Image *) NULL);
   if (SetImageStorageClass(mean_image,DirectClass) == MagickFalse)
@@ -2210,7 +2225,7 @@ MagickExport Image *MeanShiftImage(const Image *image,const size_t width,
   pixel_view=AcquireVirtualCacheView(image,exception);
   mean_view=AcquireAuthenticCacheView(mean_image,exception);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status,progress) \
+  #pragma omp parallel for schedule(static) shared(status,progress) \
     magick_number_threads(mean_image,mean_image,mean_image->rows,1)
 #endif
   for (y=0; y < (ssize_t) mean_image->rows; y++)
@@ -2308,7 +2323,7 @@ MagickExport Image *MeanShiftImage(const Image *image,const size_t width,
               }
           }
         }
-        gamma=1.0/count;
+        gamma=PerceptibleReciprocal(count);
         mean_location.x=gamma*sum_location.x;
         mean_location.y=gamma*sum_location.y;
         mean_pixel.red=gamma*sum_pixel.red;
@@ -2343,10 +2358,10 @@ MagickExport Image *MeanShiftImage(const Image *image,const size_t width,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-        #pragma omp critical (MagickCore_MeanShiftImage)
+        #pragma omp atomic
 #endif
-        proceed=SetImageProgress(image,MeanShiftImageTag,progress++,
-          image->rows);
+        progress++;
+        proceed=SetImageProgress(image,MeanShiftImageTag,progress,image->rows);
         if (proceed == MagickFalse)
           status=MagickFalse;
       }
