@@ -179,7 +179,7 @@ static LinkedListInfo *AcquirePolicyCache(const char *filename,
   if (cache == (LinkedListInfo *) NULL)
     ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   status=MagickTrue;
-#if defined(MAGICKCORE_ZERO_CONFIGURATION_SUPPORT)
+#if MAGICKCORE_ZERO_CONFIGURATION_SUPPORT
   status=LoadPolicyCache(cache,ZeroConfigurationPolicy,"[zero-configuration]",0,
     exception);
 #else
@@ -431,8 +431,31 @@ MagickExport const PolicyInfo **GetPolicyInfoList(const char *pattern,
 %    o exception: return any errors or warnings in this structure.
 %
 */
-MagickExport char **GetPolicyList(const char *pattern,
-  size_t *number_policies,ExceptionInfo *exception)
+
+static char *AcquirePolicyString(const char *source,const size_t pad)
+{
+  char
+    *destination;
+
+  size_t
+    length;
+
+  length=0;
+  if (source != (char *) NULL)
+    length+=strlen(source);
+  destination=(char *) NULL;
+  if (~length >= pad) 
+    destination=(char *) AcquireMagickMemory((length+pad)*sizeof(*destination));
+  if (destination == (char *) NULL)
+    ThrowFatalException(ResourceLimitFatalError,"UnableToAcquireString");
+  if (source != (char *) NULL)
+    (void) memcpy(destination,source,length*sizeof(*destination));
+  destination[length]='\0';
+  return(destination);
+}
+
+MagickExport char **GetPolicyList(const char *pattern,size_t *number_policies,
+  ExceptionInfo *exception)
 {
   char
     **policies;
@@ -467,7 +490,7 @@ MagickExport char **GetPolicyList(const char *pattern,
   {
     if ((p->stealth == MagickFalse) &&
         (GlobExpression(p->name,pattern,MagickFalse) != MagickFalse))
-      policies[i++]=ConstantString(p->name);
+      policies[i++]=AcquirePolicyString(p->name,1);
     p=(const PolicyInfo *) GetNextValueInLinkedList(policy_cache);
   }
   UnlockSemaphoreInfo(policy_semaphore);
@@ -519,7 +542,7 @@ MagickExport char *GetPolicyValue(const char *name)
   value=policy_info->value;
   if ((value == (const char *) NULL) || (*value == '\0'))
     return((char *) NULL);
-  return(ConstantString(value));
+  return(AcquirePolicyString(value,1));
 }
 
 /*
@@ -763,7 +786,7 @@ static MagickBooleanType LoadPolicyCache(LinkedListInfo *cache,const char *xml,
   const char *filename,const size_t depth,ExceptionInfo *exception)
 {
   char
-    keyword[MaxTextExtent],
+    keyword[MagickPathExtent],
     *token;
 
   const char
@@ -787,8 +810,8 @@ static MagickBooleanType LoadPolicyCache(LinkedListInfo *cache,const char *xml,
     return(MagickFalse);
   status=MagickTrue;
   policy_info=(PolicyInfo *) NULL;
-  token=AcquireString(xml);
-  extent=strlen(token)+MaxTextExtent;
+  token=AcquirePolicyString(xml,MagickPathExtent);
+  extent=strlen(token)+MagickPathExtent;
   for (q=(const char *) xml; *q != '\0'; )
   {
     /*
@@ -797,7 +820,7 @@ static MagickBooleanType LoadPolicyCache(LinkedListInfo *cache,const char *xml,
     (void) GetNextToken(q,&q,extent,token);
     if (*token == '\0')
       break;
-    (void) CopyMagickString(keyword,token,MaxTextExtent);
+    (void) CopyMagickString(keyword,token,MagickPathExtent);
     if (LocaleNCompare(keyword,"<!DOCTYPE",9) == 0)
       {
         /*
@@ -823,7 +846,7 @@ static MagickBooleanType LoadPolicyCache(LinkedListInfo *cache,const char *xml,
         */
         while (((*token != '/') && (*(token+1) != '>')) && (*q != '\0'))
         {
-          (void) CopyMagickString(keyword,token,MaxTextExtent);
+          (void) CopyMagickString(keyword,token,MagickPathExtent);
           (void) GetNextToken(q,&q,extent,token);
           if (*token != '=')
             continue;
@@ -836,17 +859,17 @@ static MagickBooleanType LoadPolicyCache(LinkedListInfo *cache,const char *xml,
               else
                 {
                   char
-                    path[MaxTextExtent],
+                    path[MagickPathExtent],
                     *xml;
 
                   GetPathComponent(filename,HeadPath,path);
                   if (*path != '\0')
                     (void) ConcatenateMagickString(path,DirectorySeparator,
-                      MaxTextExtent);
+                      MagickPathExtent);
                   if (*token == *DirectorySeparator)
-                    (void) CopyMagickString(path,token,MaxTextExtent);
+                    (void) CopyMagickString(path,token,MagickPathExtent);
                   else
-                    (void) ConcatenateMagickString(path,token,MaxTextExtent);
+                    (void) ConcatenateMagickString(path,token,MagickPathExtent);
                   xml=FileToXML(path,~0UL);
                   if (xml != (char *) NULL)
                     {
@@ -868,7 +891,7 @@ static MagickBooleanType LoadPolicyCache(LinkedListInfo *cache,const char *xml,
         if (policy_info == (PolicyInfo *) NULL)
           ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
         (void) memset(policy_info,0,sizeof(*policy_info));
-        policy_info->path=ConstantString(filename);
+        policy_info->path=AcquirePolicyString(filename,1);
         policy_info->exempt=MagickFalse;
         policy_info->signature=MagickCoreSignature;
         continue;
@@ -909,7 +932,7 @@ static MagickBooleanType LoadPolicyCache(LinkedListInfo *cache,const char *xml,
       {
         if (LocaleCompare((char *) keyword,"name") == 0)
           {
-            policy_info->name=ConstantString(token);
+            policy_info->name=AcquirePolicyString(token,1);
             break;
           }
         break;
@@ -919,7 +942,7 @@ static MagickBooleanType LoadPolicyCache(LinkedListInfo *cache,const char *xml,
       {
         if (LocaleCompare((char *) keyword,"pattern") == 0)
           {
-            policy_info->pattern=ConstantString(token);
+            policy_info->pattern=AcquirePolicyString(token,1);
             break;
           }
         break;
@@ -950,7 +973,7 @@ static MagickBooleanType LoadPolicyCache(LinkedListInfo *cache,const char *xml,
       {
         if (LocaleCompare((char *) keyword,"value") == 0)
           {
-            policy_info->value=ConstantString(token);
+            policy_info->value=AcquirePolicyString(token,1);
             break;
           }
         break;
