@@ -17,13 +17,13 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://www.imagemagick.org/script/license.php                           %
+%    https://imagemagick.org/script/license.php                               %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -79,7 +79,7 @@ static struct
     (*unregister_module)(void);
 } MagickModules[] =
 {
-#if !defined(MAGICKCORE_MODULES_SUPPORT)
+#if !defined(MAGICKCORE_BUILD_MODULES)
   { "AAI", MagickFalse, RegisterAAIImage, UnregisterAAIImage },
   { "ART", MagickFalse, RegisterARTImage, UnregisterARTImage },
   { "AVS", MagickFalse, RegisterAVSImage, UnregisterAVSImage },
@@ -118,7 +118,6 @@ static struct
   { "EXR", MagickFalse, RegisterEXRImage, UnregisterEXRImage },
 #endif
   { "FAX", MagickFalse, RegisterFAXImage, UnregisterFAXImage },
-  { "FD", MagickFalse, RegisterFDImage, UnregisterFDImage },
   { "FITS", MagickFalse, RegisterFITSImage, UnregisterFITSImage },
 #if defined(MAGICKCORE_FLIF_DELEGATE)
   { "FLIF", MagickFalse, RegisterFLIFImage, UnregisterFLIFImage },
@@ -163,7 +162,6 @@ static struct
   { "MIFF", MagickFalse, RegisterMIFFImage, UnregisterMIFFImage },
   { "MONO", MagickFalse, RegisterMONOImage, UnregisterMONOImage },
   { "MPC", MagickFalse, RegisterMPCImage, UnregisterMPCImage },
-  { "MPEG", MagickFalse, RegisterMPEGImage, UnregisterMPEGImage },
   { "MPR", MagickFalse, RegisterMPRImage, UnregisterMPRImage },
   { "MSL", MagickFalse, RegisterMSLImage, UnregisterMSLImage },
   { "MTV", MagickFalse, RegisterMTVImage, UnregisterMTVImage },
@@ -220,6 +218,7 @@ static struct
   { "UYVY", MagickFalse, RegisterUYVYImage, UnregisterUYVYImage },
   { "VICAR", MagickFalse, RegisterVICARImage, UnregisterVICARImage },
   { "VID", MagickFalse, RegisterVIDImage, UnregisterVIDImage },
+  { "VIDEO", MagickFalse, RegisterVIDEOImage, UnregisterVIDEOImage },
   { "VIFF", MagickFalse, RegisterVIFFImage, UnregisterVIFFImage },
   { "VIPS", MagickFalse, RegisterVIPSImage, UnregisterVIPSImage },
   { "WBMP", MagickFalse, RegisterWBMPImage, UnregisterWBMPImage },
@@ -379,6 +378,9 @@ MagickExport MagickBooleanType RegisterStaticModule(const char *module,
   char
     module_name[MagickPathExtent];
 
+  PolicyRights
+    rights;
+
   register const CoderInfo
     *p;
 
@@ -393,6 +395,14 @@ MagickExport MagickBooleanType RegisterStaticModule(const char *module,
   */
   assert(module != (const char *) NULL);
   (void) CopyMagickString(module_name,module,MagickPathExtent);
+  rights=ReadPolicyRights;
+  if (IsRightsAuthorized(ModulePolicyDomain,rights,module) == MagickFalse)
+    {
+      errno=EPERM;
+      (void) ThrowMagickException(exception,GetMagickModule(),PolicyError,
+        "NotAuthorized","`%s'",module);
+      return(MagickFalse);
+    }
   p=GetCoderInfo(module,exception);
   if (p != (CoderInfo *) NULL)
     (void) CopyMagickString(module_name,p->name,MagickPathExtent);
