@@ -40,7 +40,7 @@ static inline double SiPrefixToDoubleInterval(const char *string,
   return(value);
 }
 
-static inline char *StringLocateSubstring(const char *haystack,
+static inline const char *StringLocateSubstring(const char *haystack,
   const char *needle)
 {
 #if defined(MAGICKCORE_HAVE_STRCASESTR)
@@ -51,7 +51,7 @@ static inline char *StringLocateSubstring(const char *haystack,
       length_needle,
       length_haystack;
 
-    register ssize_t
+    register size_t
       i;
 
     if (!haystack || !needle)
@@ -65,9 +65,9 @@ static inline char *StringLocateSubstring(const char *haystack,
 
       for (j=0; j < length_needle; j++)
       {
-        unsigned char c1 = haystack[i+j];
-        unsigned char c2 = needle[j];
-        if (toupper(c1) != toupper(c2))
+        unsigned char c1 = (unsigned char) haystack[i+j];
+        unsigned char c2 = (unsigned char) needle[j];
+        if (toupper((int) c1) != toupper((int) c2))
           goto next;
       }
       return((char *) haystack+i);
@@ -110,6 +110,17 @@ static inline long StringToLong(const char *magick_restrict value)
   return(strtol(value,(char **) NULL,10));
 }
 
+static inline size_t StringToSizeType(const char *string,const double interval)
+{
+  double
+    value;
+
+  value=SiPrefixToDoubleInterval(string,interval);
+  if (value >= (double) MagickULLConstant(~0))
+    return(~0UL);
+  return((size_t) value);
+}
+
 static inline unsigned long StringToUnsignedLong(
   const char *magick_restrict value)
 {
