@@ -344,6 +344,7 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
         continue;
       }
     pend=image != (Image *) NULL ? MagickTrue : MagickFalse;
+    image_info->ping=MagickFalse;
     switch (*(option+1))
     {
       case 'a':
@@ -450,7 +451,6 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
               ThrowIdentifyException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowIdentifyInvalidArgumentException(option,argv[i]);
-            image_info->ping=MagickFalse;
             break;
           }
         if (LocaleCompare("concurrent",option+1) == 0)
@@ -491,8 +491,6 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
                   ThrowIdentifyException(OptionError,"NoSuchOption",argv[i]);
                 break;
               }
-            if (LocaleNCompare("identify:locate",argv[i],15) == 0)
-              image_info->ping=MagickFalse;
             break;
           }
         if (LocaleCompare("density",option+1) == 0)
@@ -622,7 +620,10 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
       {
         if ((LocaleCompare("help",option+1) == 0) ||
             (LocaleCompare("-help",option+1) == 0))
-          return(IdentifyUsage());
+          {
+            DestroyIdentify();
+            return(IdentifyUsage());
+          }
         ThrowIdentifyException(OptionError,"UnrecognizedOption",option)
       }
       case 'i':
@@ -640,8 +641,8 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
             interlace=ParseCommandOption(MagickInterlaceOptions,MagickFalse,
               argv[i]);
             if (interlace < 0)
-              ThrowIdentifyException(OptionError,
-                "UnrecognizedInterlaceType",argv[i]);
+              ThrowIdentifyException(OptionError,"UnrecognizedInterlaceType",
+                argv[i]);
             break;
           }
         if (LocaleCompare("interpolate",option+1) == 0)
@@ -754,7 +755,10 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
       case 'p':
       {
         if (LocaleCompare("ping",option+1) == 0)
-          break;
+          {
+            image_info->ping=MagickTrue;
+            break;
+          }
         if (LocaleCompare("precision",option+1) == 0)
           {
             if (*option == '+')
